<?php

declare(strict_types=1);

namespace atk4\ui\demo;

use atk4\ui\Button;

/** @var \atk4\ui\App $app */
require_once __DIR__ . '/../init-app.php';

\atk4\ui\Button::addTo($app, ['js Event Executor', 'small right floated basic blue', 'iconRight' => 'right arrow'])
    ->link(['jsactions']);
\atk4\ui\View::addTo($app, ['ui' => 'ui clearing divider']);

\atk4\ui\Header::addTo($app, ['Extensions to ATK Data Actions', 'subHeader' => 'Demonstrate how to augment your models with actions and vizualize those inside UI']);

// Actions can be added easily to the model

$files = new FileLock($app->db);

// This action must appear on top of the CRUD
$action = $files->addAction(
    'import_from_filesystem',
    [
        'callback' => 'importFromFilesystem',
        'preview' => function ($model, $path) {
            return 'Considering path: ' . $path;
        },
        'args' => [
            'path' => ['type' => 'string', 'required' => true],
        ],
        'scope' => \atk4\data\UserAction\Generic::NO_RECORDS,
    ]
);

$files->addAction('download', function (\atk4\data\Model $m) {
    $len = strlen(file_get_contents($m->get('name')));

    return "{$len} bytes downloaded..";
});

//$files->getAction('download')->system = true;

$app->add($grid = new \atk4\ui\GridLayout(['columns' => 3]));

$grid->add($executor = new \atk4\ui\ActionExecutor\Basic(['executorButton' => [Button::class, 'Import', 'primary']]), 'r1c1');
$executor->setAction($action);
$executor->ui = 'segment';
$executor->description = 'Execute action using "Basic" executor and path="." argument';
$executor->setArguments(['path' => '.']);
$executor->onHook(\atk4\ui\ActionExecutor\Basic::HOOK_AFTER_EXECUTE, function ($x) {
    return new \atk4\ui\jsToast('Done!');
});

$grid->add($executor = new \atk4\ui\ActionExecutor\ArgumentForm(), 'r1c2');
$executor->setAction($action);
$executor->description = 'ArgumentForm executor will ask user about arguments';
$executor->ui = 'segment';
$executor->onHook(\atk4\ui\ActionExecutor\Basic::HOOK_AFTER_EXECUTE, function ($x, $ret) {
    return new \atk4\ui\jsToast('Imported!');
});

$grid->add($executor = new \atk4\ui\ActionExecutor\Preview(), 'r1c3');
$executor->setAction($action);
$executor->ui = 'segment';
$executor->previewType = 'console';
$executor->description = 'Displays preview in console prior to executing';
$executor->setArguments(['path' => '.']);
$executor->onHook(\atk4\ui\ActionExecutor\Basic::HOOK_AFTER_EXECUTE, function ($x, $ret) {
    return new \atk4\ui\jsToast('Confirm!');
});

\atk4\ui\CRUD::addTo($app, ['ipp' => 5])->setModel($files);
