<?php

declare(strict_types=1);

namespace atk4\ui\demo;

/** @var \atk4\ui\App $app */
require_once __DIR__ . '/../init-app.php';

// create header
\atk4\ui\Header::addTo($app, ['Lookup Input']);

\atk4\ui\FormField\Lookup::addTo($app, ['placeholder' => 'Search country', 'label' => 'Country: '])->setModel(new Country($app->db));

// create form
$form = \atk4\ui\Form::addTo($app, ['segment']);
\atk4\ui\Label::addTo($form, ['Lookup countries', 'top attached'], ['AboveFields']);

$m = new \atk4\data\Model($app->db, 'test');

// Without Lookup
$m->hasOne('country1', new Country());

// With Lookup
$m->hasOne('country2', [new Country(), 'ui' => ['form' => [
    new DemoLookup(),
    'plus' => true,
]]]);

$form->setModel($m);

$form->addField('country3', [
    \atk4\ui\FormField\Lookup::class,
    'model' => new Country($app->db),
    'placeholder' => 'Search for country by name or iso value',
    'search' => ['name', 'iso', 'iso3'],
]);

$form->onSubmit(function (\atk4\ui\Form $form) {
    $str = $form->model->ref('country1')->get('name') . ' ' . $form->model->ref('country2')->get('name') . ' ' . (new Country($form->app->db))->tryLoad($form->model->get('country3'))->get('name');
    $view = new \atk4\ui\Message('Select:'); // need in behat test.
    $view->init();
    $view->text->addParagraph($str);

    return $view;
});

\atk4\ui\Header::addTo($app, ['Lookup input using label']);

// from seed
\atk4\ui\FormField\Lookup::addTo($app, ['placeholder' => 'Search country', 'label' => 'Country: '])->setModel(new Country($app->db));

// through constructor
\atk4\ui\FormField\Lookup::addTo($app, ['placeholder' => 'Weight', 'labelRight' => new \atk4\ui\Label(['kg', 'basic'])]);
\atk4\ui\FormField\Lookup::addTo($app, ['label' => '$', 'labelRight' => new \atk4\ui\Label(['.00', 'basic'])]);

\atk4\ui\FormField\Lookup::addTo($app, [
    'iconLeft' => 'tags',
    'labelRight' => new \atk4\ui\Label(['Add Tag', 'tag']),
]);

// left/right corner is not supported, but here is work-around:
$label = new \atk4\ui\Label();
$label->addClass('left corner');
\atk4\ui\Icon::addTo($label, ['asterisk']);

\atk4\ui\FormField\Lookup::addTo($app, [
    'label' => $label,
])->addClass('left corner');

\atk4\ui\Header::addTo($app, ['Lookup input inside modal']);

$modal = \atk4\ui\Modal::addTo($app)->set(function ($p) {
    $a = \atk4\ui\FormField\Lookup::addTo($p, ['placeholder' => 'Search country', 'label' => 'Country: ']);
    $a->setModel(new Country($p->app->db));
});
\atk4\ui\Button::addTo($app, ['Open Lookup on a Modal window'])->on('click', $modal->show());
